slepc-3.18.0 2022-10-01
Report Typos and Errors

# FNGetScale

Gets the scaling parameters that define the matematical function.

### Synopsis

    #include "slepcfn.h"
    PetscErrorCode FNGetScale(FN fn,PetscScalar *alpha,PetscScalar *beta)

Not Collective

### Input Parameter

| fn | - the math function context

### Output Parameters

| alpha | - inner scaling (argument)
| beta | - outer scaling (result)

### See Also

FNSetScale()

### Level

intermediate

### Location

src/sys/classes/fn/interface/fnbasic.c

### Examples

src/eps/tutorials/ex36.c.html
Index of all FN routines
Table of Contents for all manual pages
Index of all manual pages